@@ -12,6 +12,41 @@
 
 (* Module [Facile]: end-user interface to the FaCiLe library *)
 
+module Debug :
+  sig
+    val level : string ref
+    val log : out_channel ref
+    val call : char -> (out_channel -> unit) -> unit
+    val internal_error : string -> 'a
+    val fatal_error : string -> 'a
+    val print_in_assert : bool -> string -> bool
+  end
+
+module Misc :
+   sig
+     val last_and_length : 'a list -> 'a * int
+     val gen_int_fun : unit -> (unit -> int)
+     val arg_min_array : ('a -> 'b) -> 'a array -> (int * 'b)
+     val arg_max_array : ('a -> 'b) -> 'a array -> (int * 'b)
+     val int_overflow : float -> bool
+     module Operators :
+       sig
+	 val (=+) : int ref -> int -> unit
+	 val (=+.) : float ref -> float -> unit
+	 val min : int -> int -> int
+	 val max : int -> int -> int
+	 val ( * ) : int -> int -> int
+	 val (+) : int -> int -> int
+	 val (-) : int -> int -> int
+	 val sign : int -> int
+	 val ( /+ ) : int -> int -> int
+	 val ( /- ) : int -> int -> int
+       end
+     val iter : ('a -> 'a) -> int -> 'a -> 'a
+     val goedel : (int -> 'a -> 'a) -> int -> 'a -> 'a
+     val protect : string -> (unit -> 'a) -> 'a
+   end
+
 module Domain :
     sig
       type elt = int
