@@ -53,7 +53,7 @@ let rec less_than x1 x2 d =
     let min1, max1 = Fd.min_max x1
     and min2, max2 = Fd.min_max x2 in
     max1 <= min2 + d || (if min1 > max2 + d then false else raise C.DontKnow)
-  and not () = less_than x2 x1 (1-d)
+  and not () = less_than x2 x1 (-1-d)
   and delay ct =
     delay [Fd.on_min] x1 ct;
     delay [Fd.on_max] x2 ct
